@@ -16,7 +16,6 @@ OC.L10N.register(
     "Share with users or groups" : "Deel met gebruikers of groepe",
     "No users or groups" : "Geen gebruikers of groepe",
     "can edit" : "kan wysig",
-    "Address book name" : "Adresboeknaam",
     "First name" : "Naam",
     "Last name" : "Van",
     "Display name" : "Vertoonnaam",
@@ -88,7 +87,6 @@ OC.L10N.register(
     "Female" : "Vroulik",
     "Male" : "Manlik",
     "None" : "Geen",
-    "Unknown" : "Onbekend",
-    "Timezone" : "Tydsone"
+    "Unknown" : "Onbekend"
 },
 "nplurals=2; plural=(n != 1);");
