@@ -57,7 +57,6 @@ OC.L10N.register(
     "Select local file" : "로컬 파일 선택",
     "Importing is disabled because there are no address books available" : "주소록을 찾을 수 없어서 가져올 수 없습니다.",
     "Choose a vCard file to import" : "불러올 vCard 파일을 고르세요",
-    "Address book name" : "주소록 이름",
     "An error occurred, unable to create the address book" : "오류가 발생하여 주소록을 생성할 수 없습니다.",
     "First name" : "이름",
     "Last name" : "성",
@@ -245,7 +244,6 @@ OC.L10N.register(
     "Male" : "남성",
     "None" : "없음",
     "Unknown" : "알 수 없음",
-    "Timezone" : "시간대",
     "Spoken languages" : "사용 언어",
     "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["연락처 {failed}개를 읽을 수 없음"],
     "Some circle(s) an error occurred. Check the console for more details." : "일부 서클에서 오류가 발생함. 자세한 사항은 콘솔 참조하십시오.",
