@@ -61,6 +61,7 @@ OC.L10N.register(
     "Import from Files" : "从文件导入",
     "Importing is disabled because there are no address books available" : "导入已被禁用，因为没有可用的地址簿",
     "Choose a vCard file to import" : "选择要导入的 vCard（电子名片） 文件",
+    "Add new address book" : "添加新通讯录",
     "An error occurred, unable to create the address book" : "发生错误，无法创建通讯录",
     "First name" : "名",
     "Last name" : "姓",
@@ -71,6 +72,7 @@ OC.L10N.register(
     "Sort by {sorting}" : "以 {sorting} 排序",
     "Update avatars from social media" : "从社交媒体更新头像",
     "(refreshed once per week)" : "(每周刷新)",
+    "Address books" : "通讯录",
     "An error happened during the config change" : "更改配置时发生一个错误",
     "Circle name" : "圈子名称",
     "Circle owned by {owner}" : "圈子所有者为  {owner}",
