@@ -61,6 +61,7 @@ OC.L10N.register(
     "Import from Files" : "從檔案導入",
     "Importing is disabled because there are no address books available" : "已停用導入，因為沒有可用的通訊錄",
     "Choose a vCard file to import" : "選取要導入的 vCard 檔案",
+    "Add new address book" : "添加新通訊錄",
     "An error occurred, unable to create the address book" : "發生錯誤，無法建立通訊錄",
     "First name" : "名",
     "Last name" : "姓",
@@ -71,6 +72,7 @@ OC.L10N.register(
     "Sort by {sorting}" : "按 {sorting} 排序",
     "Update avatars from social media" : "從社群媒體更新大頭照",
     "(refreshed once per week)" : "（每週重新整理一次）",
+    "Address books" : "通訊錄",
     "An error happened during the config change" : "配置更改期間發生錯誤",
     "Circle name" : "社交圈子名稱",
     "Circle owned by {owner}" : "{owner} 擁有的社交圈子",
